package checkmk

import (
	"context"
	"log"
	"testing"
	"time"
)

func TestRunLocalCommand(t *testing.T) {
	cmd := &LocalCommandBackend{
		Timeout:       time.Second,
		SatelliteName: "Local",
	}
	out, err := cmd.CmkRunCommand(context.Background(), "2123", []string{"echo", "-n", "hallo welt"}, map[string]string{})
	if err != nil {
		t.Fatal(err)
	}
	if out != "hallo welt" {
		t.Fatal("output != \"hallo welt\": \"", out, "\"")
	}
}

func TestRunLocalCommandTimeout(t *testing.T) {
	begin := time.Now()
	cmd := &LocalCommandBackend{
		Timeout:       time.Second / 2,
		SatelliteName: "Local",
	}
	_, err := cmd.CmkRunCommand(context.Background(), "2123", []string{"bash", "-c", "sleep 1 && echo -n test"}, map[string]string{})
	if err == nil {
		t.Fatal("no timeout error")
	} else {
		log.Println(err)
	}
	if time.Now().After(begin.Add(time.Second)) {
		t.Fatal("no timeout error")
	}
}

func TestRunLocalCommandError(t *testing.T) {
	cmd := &LocalCommandBackend{
		Timeout:       time.Second,
		SatelliteName: "Local",
	}
	out, err := cmd.CmkRunCommand(context.Background(), "2123", []string{"bash", "-c", "echo -n \"test\"; exit 1"}, map[string]string{})
	if err == nil {
		t.Fatal("expected and error status")
	}
	if out != "test" {
		t.Fatal("expected output \"test\": \"", out, "\"")
	}
}
